//******************************************************************************
// Generic Test for the RS485. The analog Input are read out and transmitted.
// Pressing m on the keyboard turn on LED 2 on the MCU board. 
// LED1 of the MCU board is blinked at each read of the ADC.
//
//
// Tested Platform: mini Controller Board PIC32
// Tested MCU: PIC32MX150F128D
// Tested Compiler: XC32 4.45
//******************************************************************************

#include "xc.h"

#define SYSTEM_CLOCK 32000000UL

#include "LTlib.h"

#include "HW_mini_Sensing_PLC.h"
#include "HW_mini_Sensing_MCU_Board.h"

#include "LTlib_utilities.h"
#include "LTlib_utilities.c"

#include "module_UART.h"  
#include "module_UART.c" 

#include "LTlib_delay.h"
#include "LTlib_delay.c"

#include "module_ADC.h"  
#include "module_ADC.c" 

#include "module_IO.h"
#include "module_IO.c"


int main (void){
    
    uint8_t readback = 0x00;
    uint8_t buffer [10];
    uint16_t ADC_value = 0;
    float ADC_value_V = 0;        
    
    IO_set_all_ports_as_inputs();  
    
    delay_set_quartz(32);
    
    RS485_TX_ENABLE_PLC_DIR = SET_AS_OUTPUT;
    RS485_RX_ENABLE_PLC_DIR = SET_AS_OUTPUT;
   
    //Set LED as output
    LED_1_DIR = SET_AS_OUTPUT;    
    LED_1 = LED_OFF;
    
    LED_2_DIR = SET_AS_OUTPUT;    
    LED_2 = LED_OFF;
  
    UART1_open (UART_BAUDRATE_115200); 
    
    RS485_TX_ENABLE_PLC = RS485_TX_ENABLED_PLC;
    RS485_RX_ENABLE_PLC = RS485_RX_DISABLED_PLC;
    delay_ms (10);
        
    UART1_write_message ("Booting..."); 
        
    delay_ms (10);
    RS485_TX_ENABLE_PLC = RS485_TX_DISABLED_PLC;
    RS485_RX_ENABLE_PLC = RS485_RX_ENABLED_PLC;
    
    while (1){
    
        delay_ms (500);
         
        LED_1 ^= 0x01;
        
        RS485_TX_ENABLE_PLC = RS485_TX_ENABLED_PLC;
        RS485_RX_ENABLE_PLC = RS485_RX_DISABLED_PLC;
        delay_ms (10);
        
        //delete byte
        UART1_write_byte(8);
        
        UART1_write_message ("Input 1 : ");        
        ADC_value = ADC_read_channel(INPUT_1_ADC_PLC); 
        ADC_value_V = ((3.3 * 11) / 1024) * (float) ADC_value;
        LTlib_float_to_string (buffer, ADC_value_V, 3);             
        UART1_write_string (buffer); 
        UART1_write_message (" V");        
        UART1_write_byte(10);
        
        UART1_write_message ("Input 2 : ");        
        ADC_value = ADC_read_channel(INPUT_2_ADC_PLC); 
        ADC_value_V = ((3.3 * 11) / 1024) * (float) ADC_value;
        LTlib_float_to_string (buffer, ADC_value_V, 3);             
        UART1_write_string (buffer); 
        UART1_write_message (" V");
        UART1_write_byte(10);
        
        delay_ms (10);
        RS485_TX_ENABLE_PLC = RS485_TX_DISABLED_PLC;
        RS485_RX_ENABLE_PLC = RS485_RX_ENABLED_PLC;
        
        LED_1 ^= 0x01;
                        
        if (UART1_data_ready() == 1){
            
            readback = UART1_read_byte();
            
            if (readback == 'm'){                
                LED_2 = LED_ON;
            } else {
                LED_2 = LED_OFF;
            }       
        }         
    }    
}
