//******************************************************************************
// Generic Test for the RS485. 
// Pressing 1 on the keyboard turns on Relay 1.
// Pressing 2 on the keyboard turns on Relay 2.
// Pressing 3 on the keyboard turns off Relay 1 and Relay 2.
//
//
// Tested Platform: mini Controller Board PIC32
// Tested MCU: PIC32MX150F128D
// Tested Compiler: XC32 4.45
//******************************************************************************

#include "xc.h"

#define SYSTEM_CLOCK 32000000UL

#include "LTlib.h"

#include "module_UART.h"  
#include "module_UART.c" 

#include "LTlib_delay.h"
#include "LTlib_delay.c"

#include "HW_mini_Sensing_MCU_Board.h"
#include "HW_mini_Sensing_PLC.h"

#include "module_IO.h"
#include "module_IO.c"

#define INPUT_DELAY 50

int main (void){
    
    uint8_t readback = 0x00;
    
    IO_set_all_ports_as_inputs();  
    
    delay_set_quartz(32);
    
    RS485_TX_ENABLE_PLC_DIR = SET_AS_OUTPUT;
    RS485_RX_ENABLE_PLC_DIR = SET_AS_OUTPUT;
    
    RELAY_1_PLC_DIR = SET_AS_OUTPUT;
    RELAY_2_PLC_DIR = SET_AS_OUTPUT;
    
    RELAY_1_PLC = OFF_STATE;
    RELAY_2_PLC = OFF_STATE;
   
    //Set LED as output
    LED_1_DIR = SET_AS_OUTPUT;    
    LED_1 = LED_OFF;
    
    LED_2_DIR = SET_AS_OUTPUT;    
    LED_2 = LED_OFF;
  
    UART1_open (UART_BAUDRATE_115200); 
    
    RS485_TX_ENABLE_PLC = RS485_TX_ENABLED_PLC;
    RS485_RX_ENABLE_PLC = RS485_RX_DISABLED_PLC;
    delay_ms (10);
        
    UART1_write_message ("Booting..."); 
        
    delay_ms (10);
    RS485_TX_ENABLE_PLC = RS485_TX_DISABLED_PLC;
    RS485_RX_ENABLE_PLC = RS485_RX_ENABLED_PLC;
    
    while (1){
    
        delay_ms (100);
         
        LED_1 ^= 0x01;
                
        if (UART1_data_ready() >= 1){
            
            readback = UART1_read_byte();
            UART1_write_byte(readback);
            
            if (readback == 'm'){                
                LED_2 = LED_ON;
            } else {
                LED_2 = LED_OFF;
            }
            
            
            if (readback == '1'){                
                RELAY_1_PLC = ON_STATE;
            }  
            
            if (readback == '2'){                
                RELAY_2_PLC = ON_STATE;
            }  
            
            if (readback == '3'){  
                RELAY_1_PLC = OFF_STATE;
                RELAY_2_PLC = OFF_STATE;
            }  
       
        } 
                
    }    
}
